@@ -1,27 +1,27 @@
 // Copyright (C) 2006 David Sugar, Tycho Softworks
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -52,49 +52,46 @@ typedef unsigned char   bit_t;
 
 static void bitmask(bit_t *bits, bit_t *mask, unsigned len)
 {
-        while(len--)
-                *(bits++) &= *(mask++);
+	while(len--)
+		*(bits++) &= *(mask++);
 }
 
 static void bitimask(bit_t *bits, bit_t *mask, unsigned len)
 {
-        while(len--)
-                *(bits++) |= ~(*(mask++));
+	while(len--)
+		*(bits++) |= ~(*(mask++));
 }
 
 static void bitset(bit_t *bits, unsigned blen)
 {
-        bit_t mask;
+	bit_t mask;
 
-        while(blen)
-        {
-                mask = (bit_t)(1 << 7);
-                while(mask && blen)
-                {
-                        *bits |= mask;
-                        mask >>= 1;
-                        --blen;
-                }
-                ++bits;
-        }
+	while(blen) {
+		mask = (bit_t)(1 << 7);
+		while(mask && blen) {
+			*bits |= mask;
+			mask >>= 1;
+			--blen;
+		}
+		++bits;
+	}
 }
 
 static unsigned bitcount(bit_t *bits, unsigned len)
 {
-        unsigned count = 0;
-        bit_t mask, test;
+	unsigned count = 0;
+	bit_t mask, test;
 
-        while(len--)
-        {
-                mask = (bit_t)(1<<7);
-                test = *bits++;
-                while(mask) {
-                        if(!(mask & test))
-                                return count;
-                        ++count;
-                        mask >>= 1;
-                }
-        }
+	while(len--) {
+		mask = (bit_t)(1<<7);
+		test = *bits++;
+		while(mask) {
+			if(!(mask & test))
+				return count;
+			++count;
+			mask >>= 1;
+		}
+	}
 	return count;
 }
 
@@ -138,8 +135,8 @@ bool IPV4Cidr::isMember(const struct sockaddr *saddr) const
 	bitmask((bit_t *)&host, (bit_t *)&netmask, sizeof(host));
 	if(!memcmp(&host, &network, sizeof(host)))
 		return true;
-	    
-        return false;
+
+	return false;
 }
 
 struct in_addr IPV4Cidr::getBroadcast(void) const
@@ -152,43 +149,41 @@ struct in_addr IPV4Cidr::getBroadcast(void) const
 
 unsigned IPV4Cidr::getMask(const char *cp) const
 {
-        unsigned dcount = 0;
-        const char *gp = cp;
-        const char *mp = strchr(cp, '/');
-        unsigned char dots[4];
+	unsigned dcount = 0;
+	const char *gp = cp;
+	const char *mp = strchr(cp, '/');
+	unsigned char dots[4];
 #ifdef	WIN32
 	DWORD mask;
 #else
 	uint32 mask;
 #endif
 
-        if(mp) 
-	{
-                if(!strchr(++mp, '.'))
-                        return atoi(mp);
-	
-                mask = inet_addr(mp);
-                return bitcount((bit_t *)&mask, sizeof(mask));
-        }
+	if(mp) {
+		if(!strchr(++mp, '.'))
+			return atoi(mp);
 
-        memset(dots, 0, sizeof(dots));
-        dots[0] = atoi(cp);
-        while(*gp && dcount < 3) 
-	{
-                if(*(gp++) == '.')
-                        dots[++dcount] = atoi(gp);
-        }
+		mask = inet_addr(mp);
+		return bitcount((bit_t *)&mask, sizeof(mask));
+	}
 
-        if(dots[3])
-                return 32;
+	memset(dots, 0, sizeof(dots));
+	dots[0] = atoi(cp);
+	while(*gp && dcount < 3) {
+		if(*(gp++) == '.')
+			dots[++dcount] = atoi(gp);
+	}
 
-        if(dots[2])
-                return 24;
+	if(dots[3])
+		return 32;
 
-        if(dots[1])
-                return 16;
+	if(dots[2])
+		return 24;
 
-        return 8;
+	if(dots[1])
+		return 16;
+
+	return 8;
 }
 
 void IPV4Cidr::set(const char *cp)
@@ -208,9 +203,8 @@ void IPV4Cidr::set(const char *cp)
 		*ep = 0;
 
 	cp = cbuf;
-	while(NULL != (cp = strchr(cp, '.')))
-	{
-		++dots;	
+	while(NULL != (cp = strchr(cp, '.'))) {
+		++dots;
 		++cp;
 	}
 
@@ -226,7 +220,7 @@ void IPV4Cidr::set(const char *cp)
 	bitmask((bit_t *)&network, (bit_t *)&netmask, sizeof(network));
 }
 
-		
+
 
 
 #ifdef	CCXX_IPV6
@@ -271,8 +265,8 @@ bool IPV6Cidr::isMember(const struct sockaddr *saddr) const
 	bitmask((bit_t *)&host, (bit_t *)&netmask, sizeof(host));
 	if(!memcmp(&host, &network, sizeof(host)))
 		return true;
-	    
-        return false;
+
+	return false;
 }
 
 struct in6_addr IPV6Cidr::getBroadcast(void) const
@@ -285,46 +279,43 @@ struct in6_addr IPV6Cidr::getBroadcast(void) const
 
 unsigned IPV6Cidr::getMask(const char *cp) const
 {
-        unsigned count = 0, rcount = 0;
-        const char *sp = strchr(cp, '/');
-        int flag = 0;
+	unsigned count = 0, rcount = 0;
+	const char *sp = strchr(cp, '/');
+	int flag = 0;
 
-        if(sp)
-                return atoi(++sp);
+	if(sp)
+		return atoi(++sp);
 
-        if(!strncmp(cp, "ff00:", 5))
-                return 8;
+	if(!strncmp(cp, "ff00:", 5))
+		return 8;
 
-        if(!strncmp(cp, "fe80:", 5))
-                return 10;
+	if(!strncmp(cp, "fe80:", 5))
+		return 10;
 
-        if(!strncmp(cp, "2002:", 5))
-                return 16;
+	if(!strncmp(cp, "2002:", 5))
+		return 16;
 
-        sp = strrchr(cp, ':');
-        while(*(++sp) == '0')
-                ++sp;
-        if(*sp)
-                return 128;
+	sp = strrchr(cp, ':');
+	while(*(++sp) == '0')
+		++sp;
+	if(*sp)
+		return 128;
 
-        while(*cp && count < 128) 
-	{
-                if(*(cp++) == ':') 
-		{
-                        count+= 16;
-                        while(*cp == '0')
-                                ++cp;
-                        if(*cp == ':') 
-			{
-                                if(!flag)
-                                        rcount = count;
-                                flag = 1;
-                        }
-                        else
-                                flag = 0;
-                }
-        }
-        return rcount;
+	while(*cp && count < 128) {
+		if(*(cp++) == ':') {
+			count+= 16;
+			while(*cp == '0')
+				++cp;
+			if(*cp == ':') {
+				if(!flag)
+					rcount = count;
+				flag = 1;
+			}
+			else
+				flag = 0;
+		}
+	}
+	return rcount;
 }
 
 void IPV6Cidr::set(const char *cp)
