@@ -19,9 +19,9 @@
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -64,7 +64,7 @@ Date::Date()
 {
 	time_t now = SysTime::getTime();
 	struct tm dt;
-       SysTime::getLocalTime(&now, &dt);
+	   SysTime::getLocalTime(&now, &dt);
 
 	toJulian(dt.tm_year + 1900, dt.tm_mon + 1, dt.tm_mday);
 }
@@ -77,7 +77,7 @@ Date::Date(struct tm *dt)
 Date::Date(time_t tm)
 {
 	struct tm dt;
-       SysTime::getLocalTime(&tm, &dt);
+	   SysTime::getLocalTime(&tm, &dt);
 	toJulian(dt.tm_year + 1900, dt.tm_mon + 1, dt.tm_mday);
 }
 
@@ -94,7 +94,7 @@ void Date::setDate(const char *str, size_t size)
 {
 	time_t now = SysTime::getTime();
 	struct tm dt;
-       SysTime::getLocalTime(&now, &dt);
+	   SysTime::getLocalTime(&now, &dt);
 	int year = 0;
 	const char *mstr = str;
 	const char *dstr = str;
@@ -102,18 +102,16 @@ void Date::setDate(const char *str, size_t size)
 	if(!size)
 		size = strlen(str);
 //0000
-	if(size == 4) 
-	{
+	if(size == 4) {
 #ifdef DEBUG
 		cout << "Date::SetDate(): 0000" << endl;
 #endif
 		year = dt.tm_year + 1900;
 		mstr = str;
 		dstr = str + 2;
-	}		
+	}
 //00/00
-	else if(size == 5)
-	{
+	else if(size == 5) {
 #ifdef DEBUG
 		cout << "Date::SetDate(): 00/00" << endl;
 #endif
@@ -122,8 +120,7 @@ void Date::setDate(const char *str, size_t size)
 		dstr = str + 3;
 	}
 //000000
-	else if(size == 6)
-	{
+	else if(size == 6) {
 #ifdef DEBUG
 		cout << "Date::SetDate(): 000000" << endl;
 #endif
@@ -133,8 +130,7 @@ void Date::setDate(const char *str, size_t size)
 		dstr = str + 4;
 	}
 //00000000
-	else if(size == 8 && str[2] >= '0' && str[2] <= '9' && str[5] >= '0' && str[5] <= '9')
-	{
+	else if(size == 8 && str[2] >= '0' && str[2] <= '9' && str[5] >= '0' && str[5] <= '9') {
 #ifdef DEBUG
 		cout << "Date::SetDate(): 00000000" << endl;
 #endif
@@ -144,8 +140,7 @@ void Date::setDate(const char *str, size_t size)
 		dstr = str + 6;
 	}
 //00/00/00
-	else if(size == 8)
-	{
+	else if(size == 8) {
 #ifdef DEBUG
 		cout << "Date::SetDate(): 00/00/00" << endl;
 #endif
@@ -156,8 +151,7 @@ void Date::setDate(const char *str, size_t size)
 	}
 
 //0000/00/00
-	else if(size == 10)
-	{
+	else if(size == 10) {
 #ifdef DEBUG
 		cout << "Date::SetDate(): 0000-00-00" << endl;
 #endif
@@ -167,22 +161,20 @@ void Date::setDate(const char *str, size_t size)
 		dstr = str + 8;
 	}
 #ifdef	CCXX_EXCEPTIONS
-	else if(Thread::getException() == Thread::throwObject)
-	{
+	else if(Thread::getException() == Thread::throwObject) {
 		throw this;
 	}
 #ifdef	COMMON_STD_EXCEPTION
-	else if(Thread::getException() == Thread::throwException)
-	{
+	else if(Thread::getException() == Thread::throwException) {
 		throw Exception("Date::setDate(): Invalid date.");
-	}	    
+	}
+#endif
 #endif
-#endif	
 	else {
 		julian = 0x7fffffffl;
 		return;
 	}
-	
+
 	ZNumber nmonth((char*)mstr, 2);
 	ZNumber nday((char*)dstr, 2);
 	toJulian(year, nmonth(), nday());
@@ -218,7 +210,7 @@ time_t Date::getDate(tm* dt) const
 	Number nyear(buf, 4);
 	Number nmonth(buf + 5, 2);
 	Number nday(buf + 8, 2);
-	
+
 	dt->tm_year = nyear() - 1900;
 	dt->tm_mon = nmonth() - 1;
 	dt->tm_mday = nday();
@@ -339,7 +331,7 @@ int Date::operator>=(const Date &d)
 void Date::toJulian(long year, long month, long day)
 {
 	julian = 0x7fffffffl;
-	
+
 	if(month < 1 || month > 12 || day < 1 || day > 31 || year == 0) {
 #ifdef	CCXX_EXCEPTIONS
 		if(Thread::getException() == Thread::throwObject) {
@@ -365,7 +357,7 @@ void Date::toJulian(long year, long month, long day)
 
 void Date::fromJulian(char *buffer) const
 {
-// The following conversion algorithm is due to 
+// The following conversion algorithm is due to
 // Henry F. Fliegel and Thomas C. Van Flandern:
 
 	ZNumber nyear(buffer, 4);
@@ -389,7 +381,7 @@ void Date::fromJulian(char *buffer) const
 	nyear = int(i);
 	nmonth = int(j);
 	nday = int(k);
-	
+
 	buffer[10] = '\0';
 }
 
@@ -429,7 +421,7 @@ Time::Time()
 {
 	time_t now = SysTime::getTime();
 	struct tm dt;
-       SysTime::getLocalTime(&now, &dt);
+	   SysTime::getLocalTime(&now, &dt);
 
 	toSeconds(dt.tm_hour, dt.tm_min, dt.tm_sec);
 }
@@ -442,7 +434,7 @@ Time::Time(struct tm *dt)
 Time::Time(time_t tm)
 {
 	struct tm dt;
-       SysTime::getLocalTime(&tm, &dt);
+	   SysTime::getLocalTime(&tm, &dt);
 	toSeconds(dt.tm_hour, dt.tm_min, dt.tm_sec);
 }
 
@@ -475,7 +467,7 @@ char *Time::getTime(char *buf) const
 
 time_t Time::getTime(void) const
 {
-    return static_cast<time_t>(seconds);
+	return static_cast<time_t>(seconds);
 }
 
 int Time::getHour(void) const
@@ -514,28 +506,24 @@ void Time::setTime(char *str, size_t size)
 		size = strlen(str);
 
 //00:00
-	if (size == 5)
-	{
+	if (size == 5) {
 		sec = 00;
 	}
-//00:00:00	
-	else if (size == 8)
-	{
+//00:00:00
+	else if (size == 8) {
 		ZNumber nsecond(str + 6, 2);
 		sec = nsecond();
 	}
 #ifdef	CCXX_EXCEPTIONS
-	else if(Thread::getException() == Thread::throwObject)
-	{
+	else if(Thread::getException() == Thread::throwObject) {
 		throw this;
 	}
 #ifdef	COMMON_STD_EXCEPTION
-	else if(Thread::getException() == Thread::throwException)
-	{
+	else if(Thread::getException() == Thread::throwException) {
 		throw Exception("Time::setTime(): Invalid time.");
 	}
 #endif
-#endif	    	
+#endif
 	else {
 		return;
 	}
@@ -621,7 +609,7 @@ int Time::operator>=(const Time &t)
 void Time::toSeconds(int hour, int minute, int second)
 {
 	seconds = -1;
-	
+
 	if (hour > 23 ||minute > 59 ||second > 59) {
 #ifdef	CCXX_EXCEPTIONS
 		if(Thread::getException() == Thread::throwObject) {
@@ -702,7 +690,7 @@ Time operator-(const int val, const Time &time)
 Datetime::Datetime(time_t tm)
 {
 	struct tm dt;
-       SysTime::getLocalTime(&tm, &dt);
+	   SysTime::getLocalTime(&tm, &dt);
 	toJulian(dt.tm_year + 1900, dt.tm_mon + 1, dt.tm_mday);
 	toSeconds(dt.tm_hour, dt.tm_min, dt.tm_sec);
 }
@@ -723,45 +711,39 @@ Datetime::Datetime(const char *a_str, size_t size)
 	str[size]=0;
 
 // 00/00 00:00
-	if (size ==  11)
-	{
+	if (size ==  11) {
 		timestr = str + 6;
 		setDate(str, 5);
 		setTime(timestr, 5);
 	}
 // 00/00/00 00:00
-	else if (size == 14)
-	{
+	else if (size == 14) {
 		timestr = str + 9;
 		setDate(str, 8);
 		setTime(timestr,5);
 	}
 // 00/00/00 00:00:00
-	else if (size == 17)
-	{
+	else if (size == 17) {
 		timestr = str + 9;
 		setDate(str, 8);
 		setTime(timestr,8);
 	}
 // 0000/00/00 00:00:00
-	else if (size == 19)
-	{
+	else if (size == 19) {
 		timestr = str + 11;
 		setDate(str, 10);
 		setTime(timestr,8);
 	}
 #ifdef	CCXX_EXCEPTIONS
-	else if(Thread::getException() == Thread::throwObject)
-	{
+	else if(Thread::getException() == Thread::throwObject) {
 		delete str;
 		throw this;
 	}
 #ifdef	COMMON_STD_EXCEPTION
-	else if(Thread::getException() == Thread::throwException)
-	{
+	else if(Thread::getException() == Thread::throwException) {
 		delete str;
 		throw Exception("Datetime::Datetime(): Invalid time.");
-	}	    	
+	}
 #endif
 #endif
 	delete str;
@@ -776,7 +758,7 @@ Datetime::Datetime() : Date(), Time()
 {
 	time_t now = SysTime::getTime();
 	struct tm dt;
-       SysTime::getLocalTime(&now, &dt);
+	   SysTime::getLocalTime(&now, &dt);
 
 	toSeconds(dt.tm_hour, dt.tm_min, dt.tm_sec);
 	toJulian(dt.tm_year + 1900, dt.tm_mon + 1, dt.tm_mday);
@@ -821,7 +803,7 @@ time_t Datetime::getDatetime(void) const
 	dt.tm_min = nminute();
 	dt.tm_sec = nsecond();
 	dt.tm_isdst = -1;
-	
+
 	return mktime(&dt);
 }
 
@@ -829,14 +811,14 @@ Datetime& Datetime::operator=(const Datetime datetime)
 {
 	julian = datetime.julian;
 	seconds = datetime.seconds;
-	
-	return *this;	
+
+	return *this;
 }
 
 Datetime& Datetime::operator+=(const Datetime &datetime)
 {
 	seconds += datetime.seconds;
-	julian += datetime.julian; 
+	julian += datetime.julian;
 	Date::update();
 	Time::update();
 	return *this;
@@ -845,7 +827,7 @@ Datetime& Datetime::operator+=(const Datetime &datetime)
 Datetime& Datetime::operator-=(const Datetime &datetime)
 {
 	seconds -= datetime.seconds;
-	julian -= datetime.julian; 
+	julian -= datetime.julian;
 	Date::update();
 	Time::update();
 	return *this;
@@ -933,7 +915,7 @@ String Datetime::strftime(const char *format) const
 	String retval;
 
 	t = getDatetime();
-       SysTime::getLocalTime(&t, &tbp);
+	   SysTime::getLocalTime(&t, &tbp);
 #ifdef	WIN32
 	last = ::strftime(buffer, 64, format, &tbp);
 #else
