@@ -1,27 +1,27 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -79,10 +79,10 @@ Socket(accept(tcp.getSocket(), NULL, NULL))
 #endif
 	{
 		setError(false);
-    if( svc )
+	if( svc )
   		svc->attach(this);
 	}
-}
+	}
 
 #ifdef  CCXX_IPV6
 SocketPort::SocketPort(SocketService *svc, TCPV6Socket &tcp) :
@@ -107,10 +107,10 @@ Socket(accept(tcp.getSocket(), NULL, NULL))
 #endif
 	{
 		setError(false);
-    if( svc )
+	if( svc )
   		svc->attach(this);
 	}
-}
+		}
 #endif
 
 SocketPort::SocketPort(SocketService *svc, const IPV4Address &ia, tpport_t port) :
@@ -132,8 +132,7 @@ Socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP)
 	detect_output = false;
 	detect_disconnect = true;
 
-	if(bind(so, (struct sockaddr *)&addr, (socklen_t)sizeof(addr)))
-	{
+	if(bind(so, (struct sockaddr *)&addr, (socklen_t)sizeof(addr))) {
 		endSocket();
 		error(errBindingFailed,"Could not bind socket",socket_errno);
 		return;
@@ -143,7 +142,7 @@ Socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP)
 
   if(svc)
   	svc->attach(this);
-}
+		}
 
 #ifdef  CCXX_IPV6
 SocketPort::SocketPort(SocketService *svc, const IPV6Address &ia, tpport_t port) :
@@ -165,8 +164,7 @@ Socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP)
 	detect_output = false;
 	detect_disconnect = true;
 
-	if(bind(so, (struct sockaddr *)&addr, (socklen_t)sizeof(addr)))
-	{
+	if(bind(so, (struct sockaddr *)&addr, (socklen_t)sizeof(addr))) {
 		endSocket();
 		error(errBindingFailed,"Could not bind socket",socket_errno);
 		return;
@@ -176,7 +174,7 @@ Socket(AF_INET6, SOCK_DGRAM, IPPROTO_UDP)
 
   if(svc)
   	svc->attach(this);
-}
+		}
 #endif
 
 SocketPort::SocketPort(SocketService *svc, const IPV4Host &ih, tpport_t port) :
@@ -207,12 +205,10 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 
 	int rtn = ::connect(so, (struct sockaddr *)&addr, (socklen_t)sizeof(addr));
 
-	if(!rtn)
-	{
+	if(!rtn) {
 		state = CONNECTED;
 	}
-	else
-	{
+	else {
 #ifndef WIN32
 		if(errno == EINPROGRESS)
 #else
@@ -221,8 +217,7 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 		{
 			state = CONNECTING;
 		}
-		else
-		{
+		else {
 			endSocket();
 			connectError();
 			return;
@@ -244,7 +239,7 @@ Socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
 
 //	if(state == CONNECTING)
 //		setDetectOutput(true);
-}
+			}
 
 #ifdef  CCXX_IPV6
 SocketPort::SocketPort(SocketService *svc, const IPV6Host &ih, tpport_t port) :
@@ -275,12 +270,10 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 
 	int rtn = ::connect(so, (struct sockaddr *)&addr, (socklen_t)sizeof(addr));
 
-	if(!rtn)
-	{
+	if(!rtn) {
 		state = CONNECTED;
 	}
-	else
-	{
+	else {
 #ifndef WIN32
 		if(errno == EINPROGRESS)
 #else
@@ -289,8 +282,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 		{
 			state = CONNECTING;
 		}
-		else
-		{
+		else {
 			endSocket();
 			connectError();
 			return;
@@ -312,7 +304,7 @@ Socket(AF_INET6, SOCK_STREAM, IPPROTO_TCP)
 
 //	if(state == CONNECTING)
 //		setDetectOutput(true);
-}
+				}
 #endif
 
 SocketPort::~SocketPort()
@@ -324,32 +316,32 @@ SocketPort::~SocketPort()
 		service->detach(this);
 	}
 	endSocket();
-}
+				}
 
 void SocketPort::expired(void)
 {
-}
+				}
 
 void SocketPort::pending(void)
 {
-}
+				}
 
 void SocketPort::output(void)
 {
-}
+				}
 
 void SocketPort::disconnect(void)
 {
-}
+				}
 
 void SocketPort::attach( SocketService* svc )
 {
 	if(service)
 		service->detach(this);
-	service = svc;	
+	service = svc;
 	if(svc)
 		svc->attach(this);
-}
+				}
 
 Socket::Error SocketPort::connect(const IPV4Address &ia, tpport_t port)
 {
@@ -380,7 +372,7 @@ Socket::Error SocketPort::connect(const IPV4Address &ia, tpport_t port)
 	ioctlsocket(so,FIONBIO,&opts);
 #endif
 	return rtn;
-}
+				}
 
 #ifdef  CCXX_IPV6
 Socket::Error SocketPort::connect(const IPV6Address &ia, tpport_t port)
@@ -412,7 +404,7 @@ Socket::Error SocketPort::connect(const IPV6Address &ia, tpport_t port)
 	ioctlsocket(so,FIONBIO,&opts);
 #endif
 	return rtn;
-}
+				}
 
 #endif
 
@@ -421,14 +413,14 @@ void SocketPort::setTimer(timeout_t ptimer)
 	TimerPort::setTimer(ptimer);
   if( service )
   	service->update();
-}
+				}
 
 void SocketPort::incTimer(timeout_t ptimer)
 {
 	TimerPort::incTimer(ptimer);
   if( service )
   	service->update();
-}
+				}
 
 void SocketPort::setDetectPending( bool val )
 {
@@ -443,10 +435,10 @@ void SocketPort::setDetectPending( bool val )
 			}
 		}
 #endif
-    if( service )
+	if( service )
   		service->update();
 	}
-}
+				}
 
 void SocketPort::setDetectOutput( bool val )
 {
@@ -461,10 +453,10 @@ void SocketPort::setDetectOutput( bool val )
 			}
 		}
 #endif
-    if( service )
+	if( service )
   		service->update();
 	}
-}
+				}
 
 #ifdef WIN32
 class SocketService::Sync
@@ -476,28 +468,23 @@ public:
 		semWrite(CreateSemaphore(NULL,1,1,NULL)),
 		flag(-1)
 	{ }
-	~Sync() 
-	{
+	~Sync() {
 		CloseHandle(sync);
 		CloseHandle(semWrite);
 	}
-	HANDLE GetSync() const 
-	{ 
-		return sync; 
+	HANDLE GetSync() const {
+		return sync;
 	}
-	void update(unsigned char flag)
-	{
+	void update(unsigned char flag) {
 		// FIXME: cancellation
 		WaitForSingleObject(semWrite,INFINITE);
 		this->flag = flag;
 		SetEvent(sync);
 	}
-	int getFlag()
-	{
+	int getFlag() {
 		int res = flag;
 		flag = -1;
-		if (res > 0)
-		{
+		if (res > 0) {
 			ReleaseSemaphore(semWrite,1,NULL);
 			ResetEvent(sync);
 		}
@@ -507,7 +494,7 @@ private:
 	HANDLE sync;
 	HANDLE semWrite;
 	int flag;
-};
+				};
 #endif
 
 SocketService::SocketService(int pri, size_t stack, const char *id) :
@@ -518,11 +505,9 @@ Thread(pri, stack), Mutex(id)
 #ifndef WIN32
 	FD_ZERO(&connect);
 	long opt;
-	if(::pipe(iosync))
-	{
+	if(::pipe(iosync)) {
 #ifdef	CCXX_EXCEPTIONS
-		switch(Thread::getException())
-		{
+		switch(Thread::getException()) {
 		case throwObject:
 			throw(this);
 			return;
@@ -544,11 +529,11 @@ Thread(pri, stack), Mutex(id)
 	FD_SET(iosync[0], &connect);
 #endif
 	opt = fcntl(iosync[0], F_GETFL);
-	fcntl(iosync[0], F_SETFL, opt | O_NDELAY);	
+	fcntl(iosync[0], F_SETFL, opt | O_NDELAY);
 #else
 	sync = new Sync();
 #endif
-}
+				}
 
 SocketService::~SocketService()
 {
@@ -563,19 +548,19 @@ SocketService::~SocketService()
 
 	while(first)
 		delete first;
-}
+				}
 
 void SocketService::onUpdate(unsigned char buf)
 {
-}
+				}
 
 void SocketService::onEvent(void)
 {
-}
+				}
 
 void SocketService::onCallback(SocketPort *port)
 {
-}
+				}
 
 void SocketService::attach(SocketPort *port)
 {
@@ -599,12 +584,10 @@ void SocketService::attach(SocketPort *port)
 
 	++count;
 	if(!first) first = port;
-	
+
 	// start thread if necessary
-	if (count == 1)
-	{
-		if (!isRunning())
-		{
+	if (count == 1) {
+		if (!isRunning()) {
 			leaveMutex();
 			start();
 			return;
@@ -612,7 +595,7 @@ void SocketService::attach(SocketPort *port)
 	}
 	leaveMutex();
 	update();
-}
+				}
 
 void SocketService::detach(SocketPort *port)
 {
@@ -625,30 +608,28 @@ void SocketService::detach(SocketPort *port)
 	} else {
 		first = port->next;
 	}
-	
+
 	if(port->next) {
 		port->next->prev = port->prev;
 	} else {
 		last = port->prev;
 	}
 	port->service = NULL;
-	
+
 	--count;
 	leaveMutex();
 	update();
-}
+				}
 
 
 
 void SocketService::update(unsigned char flag)
 {
 #ifndef WIN32
-	if(::write(iosync[1], (char *)&flag, 1) < 1)
-	{
+	if(::write(iosync[1], (char *)&flag, 1) < 1) {
 
 #ifdef	CCXX_EXCEPTIONS
-		switch(Thread::getException())
-		{
+		switch(Thread::getException()) {
 		case throwObject:
 			throw(this);
 			return;
@@ -668,7 +649,7 @@ void SocketService::update(unsigned char flag)
 #else
 	sync->update(flag);
 #endif
-}
+				}
 
 #define MUTEX_START { MutexLock _lock_(*this);
 #define MUTEX_END }
@@ -681,7 +662,7 @@ void SocketService::run(void)
 
 #ifndef WIN32
 #ifdef 	USE_POLL
-	
+
 	Poller			  mfd;
 	pollfd			* p_ufd;
 	int				  lastcount = 0;
@@ -690,13 +671,12 @@ void SocketService::run(void)
 	// probably don't need this but it can't hurt.
 	enterMutex();
 	port = first;
-	while(port)
-	{
+	while(port) {
 		port->ufd = 0;
 		port = port->next;
 	}
 	leaveMutex();
-	
+
 #else
 	struct timeval timeout, *tvp;
 	fd_set inp, out, err;
@@ -717,23 +697,19 @@ void SocketService::run(void)
 #endif
 
 	setCancel(cancelDeferred);
-	for(;;)
-	{
+	for(;;) {
 		timer = TIMEOUT_INF;
 #ifndef WIN32
-		while(1 == ::read(iosync[0], (char *)&buf, 1))
-		{
+		while(1 == ::read(iosync[0], (char *)&buf, 1)) {
 #else
-		for(;;)
-		{
+		for(;;) {
 			int f = sync->getFlag();
 			if (f < 0)
 				break;
 
 			buf = f;
 #endif
-			if(buf)
-			{
+			if(buf) {
 				onUpdate(buf);
 				continue;
 			}
@@ -747,12 +723,11 @@ void SocketService::run(void)
 #ifdef	USE_POLL
 
 		bool	reallocate = false;
-		
+
 		MUTEX_START
 		onEvent();
 		port = first;
-		while(port)
-		{
+		while(port) {
 			onCallback(port);
 			if ( ( p_ufd = port->ufd ) ) {
 
@@ -768,10 +743,10 @@ void SocketService::run(void)
 					p->disconnect();
 					continue;
 				}
-	
+
 				if ( ( POLLIN | POLLPRI ) & p_ufd->revents )
 					port->pending();
-	
+
 				if ( POLLOUT & p_ufd->revents )
 					port->output();
 
@@ -786,8 +761,7 @@ retry:
 				if(expires < timer)
 					timer = expires;
 
-			if(!expires)
-			{
+			if(!expires) {
 				port->endTimer();
 				port->expired();
 				goto retry;
@@ -802,15 +776,14 @@ retry:
 		if ( reallocate || ( ( count + 1 ) != lastcount ) ) {
 			lastcount = count + 1;
 			p_ufd = mfd.getList( count + 1 );
-	
+
 			// Set up iosync polling
 			p_ufd->fd = iosync[0];
 			p_ufd->events = POLLIN | POLLHUP;
 			p_ufd ++;
-			
+
 			port = first;
-			while(port)
-			{
+			while(port) {
 				p_ufd->fd = port->so;
 				p_ufd->events =
 					( port->detect_disconnect ? POLLHUP : 0 )
@@ -829,13 +802,12 @@ retry:
 		MUTEX_START
 		onEvent();
 		port = first;
-		while(port)
-		{
+		while(port) {
 			onCallback(port);
 			so = port->so;
 			if(FD_ISSET(so, &err)) {
 				port->detect_disconnect = false;
-				
+
 				SocketPort* p = port;
 				port = port->next;
 				p->disconnect();
@@ -856,8 +828,7 @@ retry:
 
 			// if we expire, get new scheduling now
 
-			if(!expires)
-			{
+			if(!expires) {
 				port->endTimer();
 				port->expired();
 				goto retry;
@@ -871,8 +842,7 @@ retry:
 		FD_ZERO(&err);
 		FD_SET(iosync[0],&inp);
 		port = first;
-		while(port)
-		{
+		while(port) {
 			so = port->so;
 			if(port->detect_pending)
 				FD_SET(so, &inp);
@@ -885,17 +855,16 @@ retry:
 
 			port = port->next;
 		}
-		
+
 		MUTEX_END
 		if(timer == TIMEOUT_INF)
 			tvp = NULL;
-		else
-		{
+		else {
 			tvp = &timeout;
 			timeout.tv_sec = timer / 1000;
 			timeout.tv_usec = (timer % 1000) * 1000;
 		}
-		select(hiwater, &inp, &out, &err, tvp);		
+		select(hiwater, &inp, &out, &err, tvp);
 #endif
 #else // WIN32
 		MUTEX_START
@@ -904,8 +873,7 @@ retry:
 		hv[0] = sync->GetSync();
 		numHandle = 1;
 		port = first;
-		while(port)
-		{
+		while(port) {
 			onCallback(port);
 
 			long events = 0;
@@ -920,8 +888,7 @@ retry:
 				events |= FD_CLOSE;
 
 			// !!! ignore some socket on overflow !!!
-			if (events && numHandle < MAXIMUM_WAIT_OBJECTS)
-			{
+			if (events && numHandle < MAXIMUM_WAIT_OBJECTS) {
 				WSAEventSelect(port->so,port->event,events);
 				hv[numHandle++] = port->event;
 			}
@@ -934,8 +901,7 @@ retry:
 
 			// if we expire, get new scheduling now
 
-			if(!expires)
-			{
+			if(!expires) {
 				port->endTimer();
 				port->expired();
 				goto retry;
@@ -943,29 +909,26 @@ retry:
 
 			port = port->next;
 		}
-		
+
 		MUTEX_END
 
 		// FIXME: handle thread cancellation correctly
 		DWORD res = WaitForMultipleObjects(numHandle,hv,FALSE,timer);
-		switch (res)
-		{
+		switch (res) {
 		case WAIT_OBJECT_0:
 			break;
 		case WAIT_TIMEOUT:
 			break;
 		default:
 			// FIXME: handle failures (detach SocketPort)
-			if (res >= WAIT_OBJECT_0+1 && res <= WAIT_OBJECT_0+MAXIMUM_WAIT_OBJECTS)
-			{
+			if (res >= WAIT_OBJECT_0+1 && res <= WAIT_OBJECT_0+MAXIMUM_WAIT_OBJECTS) {
 				int curr = res - (WAIT_OBJECT_0);
 				WSANETWORKEVENTS events;
 
 				// search port
 				MUTEX_START
 				port = first;
-				while(port)
-				{
+				while(port) {
 					if (port->event == hv[curr])
 						break;
 					port = port->next;
@@ -978,8 +941,7 @@ retry:
 
 				WSAEnumNetworkEvents(port->so,port->event,&events);
 
-				if(events.lNetworkEvents & FD_CLOSE) 
-				{
+				if(events.lNetworkEvents & FD_CLOSE) {
 					port->detect_disconnect = false;
 					port->disconnect();
 					continue;
@@ -994,12 +956,12 @@ retry:
 		}
 #endif
 	}
-}						
+					}
 
 #ifdef	CCXX_NAMESPACES
-}
-#endif		
-	
+				}
+#endif
+
 /** EMACS **
  * Local variables:
  * mode: c++
