@@ -11,17 +11,17 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -134,17 +134,14 @@ int URLStream::underflow(void)
 		return (unsigned char)*gptr();
 
 	rlen = (ssize_t)((gbuf + bufsize) - eback());
-	if(encoding == encodingChunked)
-	{
+	if(encoding == encodingChunked) {
 		buf = (char *)eback();
 		*buf = '\n';
-		while(!chunk && (*buf == '\n' || *buf == '\r'))
-		{
+		while(!chunk && (*buf == '\n' || *buf == '\r')) {
 			*buf = 0;
 			len = readLine(buf, rlen, timeout);
 		}
-		if(len)
-		{
+		if(len) {
 			if(!chunk)
 				chunk = strtol(buf, NULL, 16);
 
@@ -155,12 +152,10 @@ int URLStream::underflow(void)
 			rlen = -1;
 	}
 
-	if(rlen > 0)
-	{
+	if(rlen > 0) {
 		if(Socket::state == STREAM)
 			rlen = aRead((char *)eback(), rlen, timeout);
-		else if(timeout)
-		{
+		else if(timeout) {
 			if(Socket::isPending(pendingInput, timeout))
 				rlen = readData(eback(), rlen);
 			else
@@ -172,8 +167,7 @@ int URLStream::underflow(void)
 	if(encoding == encodingChunked && rlen > 0)
 		chunk -= rlen;
 
-	if(rlen < 1)
-	{
+	if(rlen < 1) {
 		if(rlen < 0)
 			clear(ios::failbit | rdstate());
 		return EOF;
@@ -181,11 +175,10 @@ int URLStream::underflow(void)
 	setg(eback(), eback(), eback() + rlen);
 	return (unsigned char)*gptr();
 }
-	
+
 void URLStream::setProxy(const char *host, tpport_t port)
 {
-	switch(family)
-	{
+	switch(family) {
 #ifdef	CCXX_IPV6
 	case IPV6:
 		v6proxyHost = host;
@@ -205,26 +198,22 @@ URLStream::Error URLStream::submit(const char *path, const char **vars, size_t b
 {
 	Error status = errInvalid, saved;
 
-	if(!strnicmp(path, "http:", 5))
-	{
+	if(!strnicmp(path, "http:", 5)) {
 		urlmethod = methodHttpGet;
 		path = strchr(path + 5, '/');
 		status = sendHTTPHeader(path, vars, buf);
 	}
-	if((status == errInvalid || status == errTimeout))
-	{
+	if((status == errInvalid || status == errTimeout)) {
 		if(Socket::state != AVAILABLE)
 			close();
 		return status;
 	}
-	else
-	{
+	else {
 		saved = status;
 		status = getHTTPHeaders();
 		if(status == errSuccess)
 			return saved;
-		else if(status == errTimeout)
-		{
+		else if(status == errTimeout) {
 			if(Socket::state != AVAILABLE)
 				close();
 		}
@@ -235,28 +224,24 @@ URLStream::Error URLStream::submit(const char *path, const char **vars, size_t b
 URLStream::Error URLStream::post(const char *path, MIMEMultipartForm &form, size_t buf)
 {
 	Error status = errInvalid, saved;
-	if(!strnicmp(path, "http:", 5))
-	{
+	if(!strnicmp(path, "http:", 5)) {
 		urlmethod = methodHttpPostMultipart;
 		path = strchr(path + 5, '/');
 		status = sendHTTPHeader(path, (const char **)form.getHeaders(), buf);
 	}
 
-	if(status == errInvalid || status == errTimeout)
-	{
+	if(status == errInvalid || status == errTimeout) {
 		if(Socket::state != AVAILABLE)
 			close();
 		return status;
 	}
 	saved = status;
 	status = getHTTPHeaders();
-	if(status == errSuccess)
-	{
+	if(status == errSuccess) {
 		form.body(dynamic_cast<std::ostream *>(this));
 		return saved;
 	}
-	if(status == errTimeout)
-	{
+	if(status == errTimeout) {
 		if(Socket::state != AVAILABLE)
 			close();
 	}
@@ -267,15 +252,13 @@ URLStream::Error URLStream::post(const char *path, const char **vars, size_t buf
 {
 	Error status = errInvalid, saved;
 
-	if(!strnicmp(path, "http:", 5))
-	{
+	if(!strnicmp(path, "http:", 5)) {
 		urlmethod = methodHttpPost;
 		path = strchr(path + 5, '/');
 		status = sendHTTPHeader(path, vars, buf);
 	}
 
-	if((status == errInvalid || status == errTimeout))
-	{
+	if((status == errInvalid || status == errTimeout)) {
 		if(Socket::state != AVAILABLE)
 			close();
 		return status;
@@ -284,8 +267,7 @@ URLStream::Error URLStream::post(const char *path, const char **vars, size_t buf
 	status = getHTTPHeaders();
 	if(status == errSuccess)
 		return saved;
-	if(status == errTimeout)
-	{
+	if(status == errTimeout) {
 		if(Socket::state != AVAILABLE)
 			close();
 	}
@@ -297,27 +279,23 @@ URLStream::Error URLStream::head(const char *path, size_t buf)
 {
 	Error status = errInvalid, saved;
 
-	if(!strnicmp(path, "http:", 5))
-	{
+	if(!strnicmp(path, "http:", 5)) {
 		urlmethod = methodHttpGet;
 		path = strchr(path + 5, '/');
 		status = sendHTTPHeader(path, NULL, buf);
 	}
 
-	if((status == errInvalid || status == errTimeout))
-	{
+	if((status == errInvalid || status == errTimeout)) {
 		if(Socket::state != AVAILABLE)
 			close();
 		return status;
 	}
-	else
-	{
+	else {
 		saved = status;
 		status = getHTTPHeaders();
 		if(status == errSuccess)
 			return saved;
-		else if(status == errTimeout)
-		{
+		else if(status == errTimeout) {
 			if(Socket::state != AVAILABLE)
 				close();
 		}
@@ -333,9 +311,8 @@ URLStream &URLStream::getline(char *buffer, size_t size)
 	// TODO: check, we mix use of streambuf with Socket::readLine...
 	iostream::getline(buffer, (unsigned long)size);
 	len = strlen(buffer);
-	
-	while(len)
-	{
+
+	while(len) {
 		if(buffer[len - 1] == '\r' || buffer[len - 1] == '\n')
 			buffer[len - 1] = 0;
 		else
@@ -367,19 +344,16 @@ URLStream::Error URLStream::get(const char *urlpath, size_t buf)
 	if(Socket::state != AVAILABLE)
 		close();
 
-	
-	if(!strnicmp(path, "file:", 5))
-	{
+
+	if(!strnicmp(path, "file:", 5)) {
 		urlmethod = methodFileGet;
 		path += 5;
 	}
-	else if(!strnicmp(path, "http:", 5))
-	{
+	else if(!strnicmp(path, "http:", 5)) {
 		urlmethod = methodHttpGet;
 		path = strchr(path + 5, '/');
 	}
-	switch(urlmethod)
-	{
+	switch(urlmethod) {
 	case methodHttpGet:
 		status = sendHTTPHeader(path, NULL, buf);
 		break;
@@ -389,31 +363,28 @@ URLStream::Error URLStream::get(const char *urlpath, size_t buf)
 		so = ::open(path, O_RDWR);
 		if(so == INVALID_SOCKET)
 			so = ::open(path, O_RDONLY);
-                // FIXME: open return the same handle type as socket call ??
+		// FIXME: open return the same handle type as socket call ??
 		if(so == INVALID_SOCKET)
 			return errInvalid;
 		Socket::state = STREAM;
 		allocate(buf);
 		return errSuccess;
 	default:
-    	        break;
+		        break;
 	}
 
 
-	if((status == errInvalid || status == errTimeout))
-	{
+	if((status == errInvalid || status == errTimeout)) {
 		if(Socket::state != AVAILABLE)
 			close();
 		return status;
 	}
-	else
-	{
+	else {
 		saved = status;
 		status = getHTTPHeaders();
 		if(status == errSuccess)
 			return saved;
-		else if(status == errTimeout)
-		{
+		else if(status == errTimeout) {
 			if(Socket::state != AVAILABLE)
 				close();
 		}
@@ -432,12 +403,11 @@ URLStream::Error URLStream::getHTTPHeaders()
 
 	chunk = ((unsigned)-1) / 2;
 	encoding = encodingBinary;
-	while(len > 0)
-	{
+	while(len > 0) {
 		len = readLine(buffer, buf, timeout);
 		if(len < 1)
 			return errTimeout;
-		
+
 		// FIXME: for multiline syntax ??
 		if(buffer[0] == ' ' || buffer[0] == '\r' || buffer[0] == '\n')
 			break;
@@ -450,20 +420,17 @@ URLStream::Error URLStream::getHTTPHeaders()
 		ep = strchr(cp, '\n');
 		if(!ep)
 			ep = &nc;
-		while(*ep == '\n' || *ep == '\r' || *ep == ' ')
-		{
+		while(*ep == '\n' || *ep == '\r' || *ep == ' ') {
 			*ep = 0;
 			if((--ep) < cp)
 				break;
 		}
-		if(!stricmp(buffer, "Transfer-Encoding"))
-		{
-			if(!stricmp(cp, "chunked"))
-			{
+		if(!stricmp(buffer, "Transfer-Encoding")) {
+			if(!stricmp(cp, "chunked")) {
 				chunk = 0;
 				encoding = encodingChunked;
 			}
-		}	
+		}
 		httpHeader(buffer, cp);
 	}
 	return status;
@@ -513,12 +480,11 @@ retry:
 	buffer[0] = 0;
 	str.seekp(0);
 #endif
-	
+
 	setString(host, sizeof(host), url);
 reformat:
 	hp = strchr(host, '/');
-	if(!hp)
-	{
+	if(!hp) {
 		host[0] = '/';
 		setString(host + 1, sizeof(host) - 1, url);
 		goto reformat;
@@ -528,14 +494,12 @@ reformat:
 	cp = strchr(hp, '/');
 	if (cp) *cp = 0;
 	ep = strrchr(hp, ':');
-	if(ep)
-	{
+	if(ep) {
 		*ep = 0;
 		++ep;
 		if(isdigit(*ep))
 			port = atoi(ep);
-		else
-		{
+		else {
 			Socket::mutex.enter();
 			svc = getservbyname(ep, "tcp");
 			if(svc)
@@ -544,8 +508,7 @@ reformat:
 		}
 	}
 
-	if(!proxyPort)
-	{
+	if(!proxyPort) {
 		const char* ep1 = url;
 		while(*ep1 == '/')
 			++ep1;
@@ -554,12 +517,10 @@ reformat:
 	        	uri = ep1;
 	}
 
-	switch(urlmethod)
-	{
+	switch(urlmethod) {
 	case methodHttpGet:
 		str << "GET ";
-		if(proxyPort)
-		{
+		if(proxyPort) {
 			str << "http:" << url;
 			if(!cp) str << '/';
 		}
@@ -569,8 +530,7 @@ reformat:
 	case methodHttpPost:
 	case methodHttpPostMultipart:
 		str << "POST ";
-		if(proxyPort)
-		{
+		if(proxyPort) {
 			str << "http:" << url;
 			if(!cp) str << '/';
 		}
@@ -581,11 +541,9 @@ reformat:
 		return errInvalid;
 	}
 
-	if(vars && urlmethod == methodHttpGet)
-	{
+	if(vars && urlmethod == methodHttpGet) {
 		str << "?";
-		while(*vars)
-		{
+		while(*vars) {
 			if(count++ && lasteq)
 				str << "&";
 			str << *vars;
@@ -593,17 +551,15 @@ reformat:
 				lasteq = true;
 			else if(strchr(*vars, '='))
 				lasteq = true;
-			else
-			{
+			else {
 				lasteq = false;
 				str << "=";
-			}				
+			}
 			++vars;
 		}
 	}
 
-	switch(protocol)
-	{
+	switch(protocol) {
 	case protocolHttp1_1:
 		str << " HTTP/1.1" << "\r\n";
 		break;
@@ -616,20 +572,19 @@ reformat:
 		m_host = hp;
 
 	str << "Host: " << hp << "\r\n";
-        if(agent)
-                str << "User-Agent: " << agent << "\r\n";
+	if(agent)
+		str << "User-Agent: " << agent << "\r\n";
 
-        if(cookie)
-                str << "Cookie: " << cookie << "\r\n";
+	if(cookie)
+		str << "Cookie: " << cookie << "\r\n";
 
-        if(pragma)
-                str << "Pragma: " << pragma << "\r\n";
+	if(pragma)
+		str << "Pragma: " << pragma << "\r\n";
 
-        if(referer)
-                str << "Referer: " << referer << "\r\n";
+	if(referer)
+		str << "Referer: " << referer << "\r\n";
 
-	switch(auth)
-	{
+	switch(auth) {
 	case authBasic:
 		str << "Authorization: Basic ";
 		snprintf(reloc, 64, "%s:%s", user, password);
@@ -639,8 +594,7 @@ reformat:
 		break;
 	}
 
-	switch(proxyAuth)
- 	{
+	switch(proxyAuth) {
 	case authBasic:
  		str << "Proxy-Authorization: Basic ";
  		snprintf(reloc, 64, "%s:%s", proxyUser, proxyPasswd);
@@ -654,20 +608,16 @@ reformat:
 
 	str << "Connection: close\r\n";
 	char **add = extraHeader();
-	if(add)
-	{
-		while(*add)
-		{
+	if(add) {
+		while(*add) {
 			str << *(add++) << ": ";
 			str << *(add++) << "\r\n";
 		}
 	}
 	if(vars)
-		switch(urlmethod)
-		{
+		switch(urlmethod) {
 		case methodHttpPost:
-			while(*args)
-			{
+			while(*args) {
 				var = *args;
 				if(count++ || !strchr(var, '='))
 					len += strlen(var) + 1;
@@ -694,16 +644,14 @@ reformat:
 	str << ends;
 #endif
 
-        if(Socket::state != AVAILABLE)
-                        close();
+	if(Socket::state != AVAILABLE)
+			close();
 #ifndef	WIN32
 #ifdef	SOICGIFINDEX
-	if (localif != NULL) 
-	{
+	if (localif != NULL) {
 		struct ifreq ifr;
 
-		switch(family)
-		{
+		switch(family) {
 #ifdef	CCXX_IPV6
 		case IPV6:
 			sockaddr_in6 source;
@@ -711,15 +659,14 @@ reformat:
 
 			memset(&ifr, 0, sizeof(ifr));
 			setString(ifr.ifr_name, sizeof(ifr.ifr_name), localif);
-			if (ioctl(so, SIOCGIFINDEX, &ifr) < 0) 
+			if (ioctl(so, SIOCGIFINDEX, &ifr) < 0)
 				return errInterface;
-			else
-			{
-				if (setsockopt(so, SOL_SOCKET, SO_BINDTODEVICE, &ifr, sizeof(ifr)) == -1) 
+			else {
+				if (setsockopt(so, SOL_SOCKET, SO_BINDTODEVICE, &ifr, sizeof(ifr)) == -1)
 					return errInterface;
-				else if(getsockname(so, (struct sockaddr*)&source,(socklen_t *) &alen) == -1) 
+				else if(getsockname(so, (struct sockaddr*)&source,(socklen_t *) &alen) == -1)
 					return errInterface;
-				else if (bind(so, (struct sockaddr*)&source, sizeof(source)) == -1) 
+				else if (bind(so, (struct sockaddr*)&source, sizeof(source)) == -1)
 					return errInterface;
 				else
 					source.sin6_port = 0;
@@ -733,15 +680,14 @@ reformat:
 
 			memset(&ifr, 0, sizeof(ifr));
 			setString(ifr.ifr_name, sizeof(ifr.ifr_name), localif);
-			if (ioctl(so, SIOCGIFINDEX, &ifr) < 0) 
+			if (ioctl(so, SIOCGIFINDEX, &ifr) < 0)
 				return errInterface;
-			else
-			{
-				if (setsockopt(so, SOL_SOCKET, SO_BINDTODEVICE, &ifr, sizeof(ifr)) == -1) 
+			else {
+				if (setsockopt(so, SOL_SOCKET, SO_BINDTODEVICE, &ifr, sizeof(ifr)) == -1)
 					return errInterface;
-				else if(getsockname(so, (struct sockaddr*)&source,(socklen_t *) &alen) == -1) 
+				else if(getsockname(so, (struct sockaddr*)&source,(socklen_t *) &alen) == -1)
 					return errInterface;
-				else if (bind(so, (struct sockaddr*)&source, sizeof(source)) == -1) 
+				else if (bind(so, (struct sockaddr*)&source, sizeof(source)) == -1)
 					return errInterface;
 				else
 					source.sin_port = 0;
@@ -752,24 +698,20 @@ reformat:
 #endif
 #endif
 
-	if(proxyPort)
-	{
-		switch(family)
-		{
+	if(proxyPort) {
+		switch(family) {
 #ifdef	CCXX_IPV6
 		case IPV6:
 			connect(v6proxyHost, proxyPort, (unsigned)buf);
 			break;
 #endif
-		case IPV4:	
+		case IPV4:
 		        connect(proxyHost, proxyPort, (unsigned)buf);
 			break;
 		}
 	}
-	else
-	{
-		switch(family)
-		{
+	else {
+		switch(family) {
 #ifdef	CCXX_IPV6
 		case IPV6:
 			connect(IPV6Host(hp), port, (unsigned)buf);
@@ -780,8 +722,8 @@ reformat:
 		}
 	}
 
-        if(!isConnected())
-                return errUnreachable;
+	if(!isConnected())
+		return errUnreachable;
 
 	// FIXME: send (or write) can send less than len bytes
 	// use stream funcion ??
@@ -791,23 +733,20 @@ reformat:
 	writeData(str.str().c_str(), _IOLEN64 str.str().length());
 #endif
 
-	if(urlmethod == methodHttpPost && vars)
-	{
+	if(urlmethod == methodHttpPost && vars) {
 #ifdef HAVE_SSTREAM
 	        str.str() = "";
 #else
 		str.seekp(0);
 #endif
 		bool sep = false;
-		while(*vars)
-		{
-                        if(sep)
+		while(*vars) {
+			if(sep)
 				writeData("&", 1);
-                        else
-                                sep = true;
+			else
+				sep = true;
 			var = *vars;
-			if(!strchr(var, '='))
-			{
+			if(!strchr(var, '=')) {
 				snprintf(reloc, sizeof(reloc), "%s=%s", var, *(++vars));
 				writeData(reloc, strlen(reloc));
 			}
@@ -825,73 +764,69 @@ cont:
 	// nothing here
 #endif
 
-        len = readLine(buffer, sizeof(buffer) - 1, timeout);
+	len = readLine(buffer, sizeof(buffer) - 1, timeout);
 	if(len < 1)
 		return errTimeout;
 
-        if(strnicmp(buffer, "HTTP/", 5))
-                return errInvalid;
+	if(strnicmp(buffer, "HTTP/", 5))
+		return errInvalid;
 
-        ref = strchr(buffer, ' ');
-        while(*ref == ' ')
-                ++ref;
+	ref = strchr(buffer, ' ');
+	while(*ref == ' ')
+		++ref;
 
-        switch(atoi(ref))
-        {
-        default:
-                return errInvalid;
+	switch(atoi(ref)) {
+		default:
+		return errInvalid;
 	case 100:
 		goto cont;
-        case 200:
-                return errSuccess;
-        case 401:
-                return errUnauthorized;
-        case 403:
-                return errForbidden;
-        case 404:
-                return errMissing;
-        case 405:
-                return errDenied;
-        case 500:
-        case 501:
-        case 502:
-        case 503:
-        case 504:
-        case 505:
-                return errFailure;
-        case 300:
-        case 301:
-        case 302:
-                break;
-        }
+		case 200:
+		return errSuccess;
+		case 401:
+		return errUnauthorized;
+		case 403:
+		return errForbidden;
+		case 404:
+		return errMissing;
+		case 405:
+		return errDenied;
+		case 500:
+		case 501:
+		case 502:
+		case 503:
+		case 504:
+		case 505:
+		return errFailure;
+		case 300:
+		case 301:
+		case 302:
+		break;
+	}
 	if(!follow)
 		return errRelocated;
-        for(;;)
-        {
-                len = readLine(reloc, sizeof(reloc), timeout);
+	for(;;) {
+		len = readLine(reloc, sizeof(reloc), timeout);
 		if(len < 1)
 			return errTimeout;
-                if(!strnicmp(reloc, "Location: ", 10))
-                        break;
-        }
-        if(!strnicmp(reloc + 10, "http:", 5))
-        {
-                url = strchr(reloc + 15, '/');
-                ep = (char *)(url + strlen(url) - 1);
-                while(*ep == '\r' || *ep == '\n')
-                        *(ep--) = 0;
-        }
-        else
-                url = reloc + 10;
-        close();
-        goto retry;
+		if(!strnicmp(reloc, "Location: ", 10))
+			break;
+	}
+	if(!strnicmp(reloc + 10, "http:", 5)) {
+		url = strchr(reloc + 15, '/');
+		ep = (char *)(url + strlen(url) - 1);
+		while(*ep == '\r' || *ep == '\n')
+			*(ep--) = 0;
+	}
+	else
+		url = reloc + 10;
+	close();
+	goto retry;
 }
 
 void URLStream::setAuthentication(Authentication a, const char *value)
 {
 	auth = a;
-	if (auth != authAnonymous)
-	{
+	if (auth != authAnonymous) {
 		if(!user)
 			user = "anonymous";
 		if(!password)
@@ -902,8 +837,7 @@ void URLStream::setAuthentication(Authentication a, const char *value)
 void URLStream::setProxyAuthentication(Authentication a, const char *value)
 {
 	proxyAuth = a;
-	if (proxyAuth != authAnonymous)
- 	{
+	if (proxyAuth != authAnonymous) {
  		if(!proxyUser)
  			proxyUser = "anonymous";
 
